Modules
- analyzer
- auto_
clone - auto_
fix - cli
- codegen
- Multi-target code generation
- compiler_
database - Compiler Database using Salsa for Incremental Compilation
- component_
analyzer - config
- ejector
- Ejector - Convert Windjammer projects to standalone Rust projects
- error
- Windjammer Compiler Error Types
- error_
catalog - error_
codes - error_
mapper - error_
statistics - error_
tui - errors
- fuzzy_
matcher - inference
- interpreter
- Windjammerscript: Tree-Walking Interpreter
- lexer
- linter
- Windjammer Linter - Compile predictably, warn helpfully
- module_
system - optimizer
- Windjammer Optimization Phases
- parser
- Windjammer Parser
- parser_
impl - parser_
recovery - Parser Error Recovery
- plugin
- source_
map - source_
map_ cache - stdlib_
scanner - Scans Rust source files to extract function signatures for the SignatureRegistry This allows the compiler to know the ownership requirements of stdlib functions
- syntax_
highlighter - test_
utils - Test Utilities for Arena-Allocated AST Construction
Macros
- test_
expr - Helper macro to create test expressions more ergonomically
- test_
pattern - Helper macro to create test patterns more ergonomically
- test_
stmt - Helper macro to create test statements more ergonomically
Enums
Functions
- build_
project - generate_
mod_ file - Generate mod.rs file with pub mod declarations and re-exports
- generate_
nested_ module_ structure - Generate nested module structure using the new Windjammer module system This replaces the old flat generate_mod_file with proper nested support
- get_
relative_ output_ path - Calculate output path that preserves directory structure
- run_
main_ cli - Main CLI entry point (called from bin/wj.rs after plugin discovery)
- run_
tests - Run tests (discovers and runs all test functions)
- strip_
main_ functions - Strip main() functions from generated Rust files (library mode)